Class: Aws::Billing::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Billing::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-billing/client.rb
Overview
An API client for Billing. To construct a client, you need to configure a :region and :credentials.
client = Aws::Billing::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_source_views(params = {}) ⇒ Types::AssociateSourceViewsResponse
Associates one or more source billing views with an existing billing view.
-
#create_billing_view(params = {}) ⇒ Types::CreateBillingViewResponse
Creates a billing view with the specified billing view attributes.
-
#delete_billing_view(params = {}) ⇒ Types::DeleteBillingViewResponse
Deletes the specified billing view.
-
#disassociate_source_views(params = {}) ⇒ Types::DisassociateSourceViewsResponse
Removes the association between one or more source billing views and an existing billing view.
-
#get_billing_view(params = {}) ⇒ Types::GetBillingViewResponse
Returns the metadata associated to the specified billing view ARN.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns the resource-based policy document attached to the resource in
JSONformat. -
#list_billing_views(params = {}) ⇒ Types::ListBillingViewsResponse
Lists the billing views available for a given time period.
-
#list_source_views_for_billing_view(params = {}) ⇒ Types::ListSourceViewsForBillingViewResponse
Lists the source views (managed Amazon Web Services billing views) associated with the billing view.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with the billing view resource.
-
#tag_resource(params = {}) ⇒ Struct
An API operation for adding one or more tags (key-value pairs) to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
-
#update_billing_view(params = {}) ⇒ Types::UpdateBillingViewResponse
An API to update the attributes of the billing view.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-billing/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1306 1307 1308 |
# File 'lib/aws-sdk-billing/client.rb', line 1306 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1309 1310 1311 |
# File 'lib/aws-sdk-billing/client.rb', line 1309 def errors_module Errors end |
Instance Method Details
#associate_source_views(params = {}) ⇒ Types::AssociateSourceViewsResponse
Associates one or more source billing views with an existing billing view. This allows creating aggregate billing views that combine data from multiple sources.
532 533 534 535 |
# File 'lib/aws-sdk-billing/client.rb', line 532 def associate_source_views(params = {}, = {}) req = build_request(:associate_source_views, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 |
# File 'lib/aws-sdk-billing/client.rb', line 1279 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Billing') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-billing' context[:gem_version] = '1.22.0' Seahorse::Client::Request.new(handlers, context) end |
#create_billing_view(params = {}) ⇒ Types::CreateBillingViewResponse
Creates a billing view with the specified billing view attributes.
643 644 645 646 |
# File 'lib/aws-sdk-billing/client.rb', line 643 def create_billing_view(params = {}, = {}) req = build_request(:create_billing_view, params) req.send_request() end |
#delete_billing_view(params = {}) ⇒ Types::DeleteBillingViewResponse
Deletes the specified billing view.
690 691 692 693 |
# File 'lib/aws-sdk-billing/client.rb', line 690 def delete_billing_view(params = {}, = {}) req = build_request(:delete_billing_view, params) req.send_request() end |
#disassociate_source_views(params = {}) ⇒ Types::DisassociateSourceViewsResponse
Removes the association between one or more source billing views and an existing billing view. This allows modifying the composition of aggregate billing views.
741 742 743 744 |
# File 'lib/aws-sdk-billing/client.rb', line 741 def disassociate_source_views(params = {}, = {}) req = build_request(:disassociate_source_views, params) req.send_request() end |
#get_billing_view(params = {}) ⇒ Types::GetBillingViewResponse
Returns the metadata associated to the specified billing view ARN.
820 821 822 823 |
# File 'lib/aws-sdk-billing/client.rb', line 820 def get_billing_view(params = {}, = {}) req = build_request(:get_billing_view, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns the resource-based policy document attached to the resource in JSON format.
865 866 867 868 |
# File 'lib/aws-sdk-billing/client.rb', line 865 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#list_billing_views(params = {}) ⇒ Types::ListBillingViewsResponse
Lists the billing views available for a given time period.
Every Amazon Web Services account has a unique PRIMARY billing view that represents the billing data available by default. Accounts that use Billing Conductor also have BILLING_GROUP billing views representing pro forma costs associated with each created billing group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
987 988 989 990 |
# File 'lib/aws-sdk-billing/client.rb', line 987 def list_billing_views(params = {}, = {}) req = build_request(:list_billing_views, params) req.send_request() end |
#list_source_views_for_billing_view(params = {}) ⇒ Types::ListSourceViewsForBillingViewResponse
Lists the source views (managed Amazon Web Services billing views) associated with the billing view.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1045 1046 1047 1048 |
# File 'lib/aws-sdk-billing/client.rb', line 1045 def list_source_views_for_billing_view(params = {}, = {}) req = build_request(:list_source_views_for_billing_view, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with the billing view resource.
1092 1093 1094 1095 |
# File 'lib/aws-sdk-billing/client.rb', line 1092 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
An API operation for adding one or more tags (key-value pairs) to a resource.
1141 1142 1143 1144 |
# File 'lib/aws-sdk-billing/client.rb', line 1141 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource. Specify only tag keys in your request. Don’t specify the value.
1182 1183 1184 1185 |
# File 'lib/aws-sdk-billing/client.rb', line 1182 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_billing_view(params = {}) ⇒ Types::UpdateBillingViewResponse
An API to update the attributes of the billing view.
1270 1271 1272 1273 |
# File 'lib/aws-sdk-billing/client.rb', line 1270 def update_billing_view(params = {}, = {}) req = build_request(:update_billing_view, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1299 1300 1301 |
# File 'lib/aws-sdk-billing/client.rb', line 1299 def waiter_names [] end |