Class: Aws::Billing::Types::ChargeAccount

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

An account that is charged all or a portion of the total Support charge and the percentage of the charge allocated to it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The account ID.

Returns:

  • (String)


401
402
403
404
405
406
# File 'lib/aws-sdk-billing/types.rb', line 401

class ChargeAccount < Struct.new(
  :account_id,
  :charge_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#charge_percentageString

The percentage of the total Support charge allocated to this account. This is 0.0 when supportAllocationMethod = Proportional.

Returns:

  • (String)


401
402
403
404
405
406
# File 'lib/aws-sdk-billing/types.rb', line 401

class ChargeAccount < Struct.new(
  :account_id,
  :charge_percentage)
  SENSITIVE = []
  include Aws::Structure
end