Class: Aws::Billing::Types::ContractAccount

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

An account that is covered by the Enterprise Support contract.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The account ID.

Returns:

  • (String)


446
447
448
449
450
451
# File 'lib/aws-sdk-billing/types.rb', line 446

class ContractAccount < Struct.new(
  :account_id,
  :is_gdn)
  SENSITIVE = []
  include Aws::Structure
end

#is_gdnBoolean

When true, Support charges are calculated on charges before private discounts. When false, they are calculated after private discounts.

Returns:

  • (Boolean)


446
447
448
449
450
451
# File 'lib/aws-sdk-billing/types.rb', line 446

class ContractAccount < Struct.new(
  :account_id,
  :is_gdn)
  SENSITIVE = []
  include Aws::Structure
end