Class: Aws::Billing::Types::CreateBillingViewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::CreateBillingViewRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you specify to ensure idempotency of the request.
-
#data_filter_expression ⇒ Types::Expression
See [Expression][1].
-
#description ⇒ String
The description of the billing view.
-
#name ⇒ String
The name of the billing view.
-
#resource_tags ⇒ Array<Types::ResourceTag>
A list of key value map specifying tags associated to the billing view being created.
-
#source_views ⇒ Array<String>
A list of billing views used as the data source for the custom billing view.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. If the original request completes successfully, any subsequent retries complete successfully without performing any further actions with an idempotent request.
A suitable default value is auto-generated. You should normally not need to pass this option.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-billing/types.rb', line 447 class CreateBillingViewRequest < Struct.new( :name, :description, :source_views, :data_filter_expression, :client_token, :resource_tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#data_filter_expression ⇒ Types::Expression
See Expression. Billing view only supports LINKED_ACCOUNT,
Tags, and CostCategories.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-billing/types.rb', line 447 class CreateBillingViewRequest < Struct.new( :name, :description, :source_views, :data_filter_expression, :client_token, :resource_tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the billing view.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-billing/types.rb', line 447 class CreateBillingViewRequest < Struct.new( :name, :description, :source_views, :data_filter_expression, :client_token, :resource_tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the billing view.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-billing/types.rb', line 447 class CreateBillingViewRequest < Struct.new( :name, :description, :source_views, :data_filter_expression, :client_token, :resource_tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
A list of key value map specifying tags associated to the billing view being created.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-billing/types.rb', line 447 class CreateBillingViewRequest < Struct.new( :name, :description, :source_views, :data_filter_expression, :client_token, :resource_tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_views ⇒ Array<String>
A list of billing views used as the data source for the custom billing view.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/aws-sdk-billing/types.rb', line 447 class CreateBillingViewRequest < Struct.new( :name, :description, :source_views, :data_filter_expression, :client_token, :resource_tags) SENSITIVE = [:name, :description] include Aws::Structure end |