Class: Aws::Billing::Types::CreditAllocationHistoryEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

A single entry in the credit allocation history, representing how a credit was applied to a specific service during a billing month.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account the credit was applied to.

Returns:

  • (String)


511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end

#applied_service_nameString

The Amazon Web Services service the credit was applied to.

Returns:

  • (String)


511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end

#billing_monthString

The billing month of the application in YYYY-MM format.

Returns:

  • (String)


511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end

#credit_amountTypes::Amount

The amount of credit applied. Negative values represent credits that reduced the bill.

Returns:



511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end

#credit_idString

The identifier of the credit that was applied.

Returns:

  • (String)


511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A human-readable description of the credit allocation.

Returns:

  • (String)


511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end

#is_estimated_billBoolean

true when the entry was applied to an in-flight bill that has not yet been finalized.

Returns:

  • (Boolean)


511
512
513
514
515
516
517
518
519
520
521
# File 'lib/aws-sdk-billing/types.rb', line 511

class CreditAllocationHistoryEntry < Struct.new(
  :credit_id,
  :credit_amount,
  :description,
  :account_id,
  :applied_service_name,
  :billing_month,
  :is_estimated_bill)
  SENSITIVE = []
  include Aws::Structure
end