Class: Aws::Billing::Types::Expression
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::Expression
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
See [Expression]. Billing view only supports ‘LINKED_ACCOUNT`, `Tags`, and `CostCategories`.
[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_billing_Expression.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cost_categories ⇒ Types::CostCategoryValues
The filter that’s based on ‘CostCategory` values.
-
#dimensions ⇒ Types::DimensionValues
The specific ‘Dimension` to use for `Expression`.
-
#tags ⇒ Types::TagValues
The specific ‘Tag` to use for `Expression`.
-
#time_range ⇒ Types::TimeRange
Specifies a time range filter for the billing view data.
Instance Attribute Details
#cost_categories ⇒ Types::CostCategoryValues
The filter that’s based on ‘CostCategory` values.
462 463 464 465 466 467 468 469 |
# File 'lib/aws-sdk-billing/types.rb', line 462 class Expression < Struct.new( :dimensions, :tags, :cost_categories, :time_range) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Types::DimensionValues
The specific ‘Dimension` to use for `Expression`.
462 463 464 465 466 467 468 469 |
# File 'lib/aws-sdk-billing/types.rb', line 462 class Expression < Struct.new( :dimensions, :tags, :cost_categories, :time_range) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Types::TagValues
The specific ‘Tag` to use for `Expression`.
462 463 464 465 466 467 468 469 |
# File 'lib/aws-sdk-billing/types.rb', line 462 class Expression < Struct.new( :dimensions, :tags, :cost_categories, :time_range) SENSITIVE = [] include Aws::Structure end |
#time_range ⇒ Types::TimeRange
Specifies a time range filter for the billing view data.
462 463 464 465 466 467 468 469 |
# File 'lib/aws-sdk-billing/types.rb', line 462 class Expression < Struct.new( :dimensions, :tags, :cost_categories, :time_range) SENSITIVE = [] include Aws::Structure end |