Class: Aws::Billing::Types::GetCreditAllocationHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::GetCreditAllocationHistoryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credit_allocation_history_list ⇒ Array<Types::CreditAllocationHistoryEntry>
Allocation entries sorted by
billingMonthin descending order. -
#failed_months ⇒ Array<String>
Billing months in
YYYY-MMformat that failed to return data. -
#next_token ⇒ String
Pagination token.
-
#partial_results ⇒ Boolean
truewhen data could not be retrieved for one or more billing months.
Instance Attribute Details
#credit_allocation_history_list ⇒ Array<Types::CreditAllocationHistoryEntry>
Allocation entries sorted by billingMonth in descending order.
904 905 906 907 908 909 910 911 |
# File 'lib/aws-sdk-billing/types.rb', line 904 class GetCreditAllocationHistoryResponse < Struct.new( :credit_allocation_history_list, :partial_results, :failed_months, :next_token) SENSITIVE = [] include Aws::Structure end |
#failed_months ⇒ Array<String>
Billing months in YYYY-MM format that failed to return data.
Non-empty only when partialResults is true.
904 905 906 907 908 909 910 911 |
# File 'lib/aws-sdk-billing/types.rb', line 904 class GetCreditAllocationHistoryResponse < Struct.new( :credit_allocation_history_list, :partial_results, :failed_months, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token. Present when more pages are available; null when
there are no more results.
904 905 906 907 908 909 910 911 |
# File 'lib/aws-sdk-billing/types.rb', line 904 class GetCreditAllocationHistoryResponse < Struct.new( :credit_allocation_history_list, :partial_results, :failed_months, :next_token) SENSITIVE = [] include Aws::Structure end |
#partial_results ⇒ Boolean
true when data could not be retrieved for one or more billing
months. The failedMonths field lists which months are missing.
904 905 906 907 908 909 910 911 |
# File 'lib/aws-sdk-billing/types.rb', line 904 class GetCreditAllocationHistoryResponse < Struct.new( :credit_allocation_history_list, :partial_results, :failed_months, :next_token) SENSITIVE = [] include Aws::Structure end |