Class: Aws::Billing::Types::GetCreditsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID. Must be a 12-digit numeric string.

Returns:

  • (String)


938
939
940
941
942
943
944
945
# File 'lib/aws-sdk-billing/types.rb', line 938

class GetCreditsRequest < Struct.new(
  :account_id,
  :start_date,
  :end_date,
  :payer_account_flag)
  SENSITIVE = []
  include Aws::Structure
end

#end_dateTime

The end date for the credit period as Unix epoch seconds. Must not be a future date and must be on or after startDate. Defaults to the current date when omitted.

Returns:

  • (Time)


938
939
940
941
942
943
944
945
# File 'lib/aws-sdk-billing/types.rb', line 938

class GetCreditsRequest < Struct.new(
  :account_id,
  :start_date,
  :end_date,
  :payer_account_flag)
  SENSITIVE = []
  include Aws::Structure
end

#payer_account_flagBoolean

When true and the caller is the management account, the response aggregates credits across the entire consolidated billing family. When false or omitted, returns only credits for the specified accountId.

Returns:

  • (Boolean)


938
939
940
941
942
943
944
945
# File 'lib/aws-sdk-billing/types.rb', line 938

class GetCreditsRequest < Struct.new(
  :account_id,
  :start_date,
  :end_date,
  :payer_account_flag)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The start date for the credit period as Unix epoch seconds. Must be a past date that is not more than one year before the current date.

Returns:

  • (Time)


938
939
940
941
942
943
944
945
# File 'lib/aws-sdk-billing/types.rb', line 938

class GetCreditsRequest < Struct.new(
  :account_id,
  :start_date,
  :end_date,
  :payer_account_flag)
  SENSITIVE = []
  include Aws::Structure
end