Class: Aws::Billing::Types::GetEnterpriseSupportChargeSummaryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

The response structure for GetEnterpriseSupportChargeSummary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bill_dateTime

The date the bill was generated.

Returns:

  • (Time)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#billing_monthString

The billing month in YYYY-MM format. This must be a month in the past.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#billing_period_end_dateTime

The end date of the billing period.

Returns:

  • (Time)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#billing_period_start_dateTime

The start date of the billing period.

Returns:

  • (Time)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#is_estimatedBoolean

When true, the Support charge amount is estimated. When false, the Support charge amount is finalized.

Returns:

  • (Boolean)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#payer_account_idString

The payer account ID that is authorized to view Enterprise Support data for all accounts in its Support profile.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#support_chargeString

The Support charge amount for the account.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#support_charge_percentageString

The percentage applied to the total Support-eligible spend to calculate the total Support charge across all accounts in the Support profile.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#support_discountString

The support discount amount.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#support_effective_pricing_planTypes::PricingPlan

The effective pricing plan used for the support charge calculation.

Returns:



1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_chargeString

The total Support charge amount for all accounts in the Support profile.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_reserved_instance_spendString

The total Support-eligible Reserved Instance spend from all accounts in the Support profile.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_savings_plan_spendString

The total Support-eligible Savings Plan spend from all accounts in the Support profile.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_spendString

The total Support-eligible Spend from all accounts in the Support profile. This includes eligible spend from usage of Amazon Web Services, Reserved Instances, and Savings Plans.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_usage_spendString

The total Support-eligible spend from usage of Amazon Web Services from all accounts in the Support profile.

Returns:

  • (String)


1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-billing/types.rb', line 1134

class GetEnterpriseSupportChargeSummaryResponse < Struct.new(
  :payer_account_id,
  :billing_month,
  :billing_period_start_date,
  :billing_period_end_date,
  :is_estimated,
  :bill_date,
  :support_charge,
  :total_support_charge,
  :support_discount,
  :total_support_eligible_spend,
  :total_support_eligible_usage_spend,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_charge_percentage,
  :support_effective_pricing_plan)
  SENSITIVE = []
  include Aws::Structure
end