Class: Aws::Billing::Types::LinkedAccountCharge

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

Enterprise Support charges for a linked account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The linked account ID.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#account_typeString

The type of account.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#billable_secondsInteger

The number of billable seconds in the billing period based on when the account was subscribed to Enterprise Support.

Returns:

  • (Integer)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#linked_time_periodsArray<Types::EnterpriseSupportTimePeriod>

The time periods during which this account was linked.



1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#payer_account_idString

The payer account ID that is authorized to view Enterprise Support data for all accounts in its Support profile.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#prorated_total_support_eligible_spendString

The prorated total support-eligible spend based on when the account was subscribed to Enterprise Support.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_time_periodsArray<Types::EnterpriseSupportTimePeriod>

The subscription time periods for this account.



1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#support_eligible_spend_by_serviceArray<Types::ServiceLevelAccountUsage>

The support-eligible spend broken down by service.



1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#total_secondsInteger

The total number of seconds in the billing period.

Returns:

  • (Integer)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_reserved_instance_spendString

The total support-eligible Reserved Instance spend for this account.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_savings_plan_spendString

The total support-eligible Savings Plan spend for this account.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end

#total_support_eligible_spendString

The total support-eligible spend for this account.

Returns:

  • (String)


1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
# File 'lib/aws-sdk-billing/types.rb', line 1368

class LinkedAccountCharge < Struct.new(
  :account_id,
  :payer_account_id,
  :account_type,
  :billable_seconds,
  :total_seconds,
  :total_support_eligible_spend,
  :prorated_total_support_eligible_spend,
  :linked_time_periods,
  :subscription_time_periods,
  :total_support_eligible_reserved_instance_spend,
  :total_support_eligible_savings_plan_spend,
  :support_eligible_spend_by_service)
  SENSITIVE = []
  include Aws::Structure
end