Class: Aws::Billing::Types::PricingPlan

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

A pricing plan for Enterprise Support billing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the pricing plan.

Returns:

  • (String)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#discount_applies_to_minimum_chargeBoolean

Whether the discount applies to the minimum Support charge.

Returns:

  • (Boolean)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#end_dateTime

The end date of the pricing plan.

Returns:

  • (Time)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_chargeString

The minimum Support charge amount for this pricing plan.

Returns:

  • (String)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the pricing plan.

Returns:

  • (String)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#plan_discount_percentString

The discount percentage applied by this pricing plan.

Returns:

  • (String)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_plan_idString

The unique identifier for the pricing plan.

Returns:

  • (String)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The start date of the pricing plan.

Returns:

  • (Time)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#tieredString

Whether the pricing plan uses tiered pricing.

Returns:

  • (String)


1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end

#tiersArray<Types::PricingPlanTier>

The pricing tiers within this plan.

Returns:



1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-billing/types.rb', line 1620

class PricingPlan < Struct.new(
  :pricing_plan_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :plan_discount_percent,
  :discount_applies_to_minimum_charge,
  :minimum_charge,
  :tiered,
  :tiers)
  SENSITIVE = []
  include Aws::Structure
end