Class: Aws::Billing::Types::PricingPlanTier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::PricingPlanTier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
A tier within an Enterprise Support pricing plan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_percentage_of_aggregate_charges ⇒ String
The additional percentage applied to aggregate charges in this tier.
-
#aggregate_charges_adjustment ⇒ String
The adjustment applied to aggregate charges.
-
#base_charge ⇒ String
The base charge for this tier.
-
#increment ⇒ String
The increment amount for incremental tier calculations.
-
#increment_charge ⇒ String
The charge per increment.
-
#incremental ⇒ Boolean
Whether the tier charges are calculated incrementally.
-
#tier_maximum ⇒ String
The maximum spend threshold for this tier.
-
#tier_minimum ⇒ String
The minimum spend threshold for this tier.
Instance Attribute Details
#additional_percentage_of_aggregate_charges ⇒ String
The additional percentage applied to aggregate charges in this tier.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#aggregate_charges_adjustment ⇒ String
The adjustment applied to aggregate charges.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#base_charge ⇒ String
The base charge for this tier.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#increment ⇒ String
The increment amount for incremental tier calculations.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#increment_charge ⇒ String
The charge per increment.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#incremental ⇒ Boolean
Whether the tier charges are calculated incrementally.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#tier_maximum ⇒ String
The maximum spend threshold for this tier.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |
#tier_minimum ⇒ String
The minimum spend threshold for this tier.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/aws-sdk-billing/types.rb', line 1671 class PricingPlanTier < Struct.new( :tier_minimum, :tier_maximum, :base_charge, :additional_percentage_of_aggregate_charges, :aggregate_charges_adjustment, :incremental, :increment, :increment_charge) SENSITIVE = [] include Aws::Structure end |