Class: Aws::Billing::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
The specified ARN in the request doesn't exist.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_id ⇒ String
Value is a list of resource IDs that were not found.
-
#resource_type ⇒ String
Value is the type of resource that was not found.
Instance Attribute Details
#message ⇒ String
1178 1179 1180 1181 1182 1183 1184 |
# File 'lib/aws-sdk-billing/types.rb', line 1178 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Value is a list of resource IDs that were not found.
1178 1179 1180 1181 1182 1183 1184 |
# File 'lib/aws-sdk-billing/types.rb', line 1178 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Value is the type of resource that was not found.
1178 1179 1180 1181 1182 1183 1184 |
# File 'lib/aws-sdk-billing/types.rb', line 1178 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |