Class: Aws::Billing::Types::UpdateBillingPreferencesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_preferences_per_keyArray<Types::BillingPreferenceForKey>

Key/value pairs to apply. All keys in a single request must be valid for the specified feature and must not be duplicated. For CREDIT_PREFERENCE_OPTIONS, all keys must reference the same creditId.

Returns:



1371
1372
1373
1374
1375
1376
# File 'lib/aws-sdk-billing/types.rb', line 1371

class UpdateBillingPreferencesRequest < Struct.new(
  :feature,
  :billing_preferences_per_key)
  SENSITIVE = []
  include Aws::Structure
end

#featureString

The feature to update. Valid values: BILLING_ALERTS, RI_SHARING, CREDIT_SHARING, CREDIT_LEVEL_SHARING, CREDIT_PREFERENCE_OPTIONS. The history features (RI_SHARING_HISTORY and CREDIT_SHARING_HISTORY) are read-only and cannot be updated.

Returns:

  • (String)


1371
1372
1373
1374
1375
1376
# File 'lib/aws-sdk-billing/types.rb', line 1371

class UpdateBillingPreferencesRequest < Struct.new(
  :feature,
  :billing_preferences_per_key)
  SENSITIVE = []
  include Aws::Structure
end