Class: Aws::Billing::Types::UpdateBillingViewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::UpdateBillingViewRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
-
#data_filter_expression ⇒ Types::Expression
See [Expression][1].
-
#description ⇒ String
The description of the billing view.
-
#name ⇒ String
The name of the billing view.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
1406 1407 1408 1409 1410 1411 1412 1413 |
# File 'lib/aws-sdk-billing/types.rb', line 1406 class UpdateBillingViewRequest < Struct.new( :arn, :name, :description, :data_filter_expression) SENSITIVE = [:name, :description] include Aws::Structure end |
#data_filter_expression ⇒ Types::Expression
See Expression. Billing view only supports LINKED_ACCOUNT,
Tags, and CostCategories.
1406 1407 1408 1409 1410 1411 1412 1413 |
# File 'lib/aws-sdk-billing/types.rb', line 1406 class UpdateBillingViewRequest < Struct.new( :arn, :name, :description, :data_filter_expression) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the billing view.
1406 1407 1408 1409 1410 1411 1412 1413 |
# File 'lib/aws-sdk-billing/types.rb', line 1406 class UpdateBillingViewRequest < Struct.new( :arn, :name, :description, :data_filter_expression) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the billing view.
1406 1407 1408 1409 1410 1411 1412 1413 |
# File 'lib/aws-sdk-billing/types.rb', line 1406 class UpdateBillingViewRequest < Struct.new( :arn, :name, :description, :data_filter_expression) SENSITIVE = [:name, :description] include Aws::Structure end |