Class: Aws::Billing::Types::UpdateBillingViewResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-billing/types.rb', line 1426

class UpdateBillingViewResponse < Struct.new(
  :arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time when the billing view was last updated.

Returns:

  • (Time)


1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-billing/types.rb', line 1426

class UpdateBillingViewResponse < Struct.new(
  :arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end