Class: Aws::Billing::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Billing::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-billing/client.rb
Overview
An API client for Billing. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Billing::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_source_views(params = {}) ⇒ Types::AssociateSourceViewsResponse
Associates one or more source billing views with an existing billing view.
-
#create_billing_view(params = {}) ⇒ Types::CreateBillingViewResponse
Creates a billing view with the specified billing view attributes.
-
#delete_billing_view(params = {}) ⇒ Types::DeleteBillingViewResponse
Deletes the specified billing view.
-
#disassociate_source_views(params = {}) ⇒ Types::DisassociateSourceViewsResponse
Removes the association between one or more source billing views and an existing billing view.
-
#get_billing_view(params = {}) ⇒ Types::GetBillingViewResponse
Returns the metadata associated to the specified billing view ARN.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns the resource-based policy document attached to the resource in ‘JSON` format.
-
#list_billing_views(params = {}) ⇒ Types::ListBillingViewsResponse
Lists the billing views available for a given time period.
-
#list_source_views_for_billing_view(params = {}) ⇒ Types::ListSourceViewsForBillingViewResponse
Lists the source views (managed Amazon Web Services billing views) associated with the billing view.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with the billing view resource.
-
#tag_resource(params = {}) ⇒ Struct
An API operation for adding one or more tags (key-value pairs) to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
-
#update_billing_view(params = {}) ⇒ Types::UpdateBillingViewResponse
An API to update the attributes of the billing view.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-billing/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1304 1305 1306 |
# File 'lib/aws-sdk-billing/client.rb', line 1304 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1307 1308 1309 |
# File 'lib/aws-sdk-billing/client.rb', line 1307 def errors_module Errors end |
Instance Method Details
#associate_source_views(params = {}) ⇒ Types::AssociateSourceViewsResponse
Associates one or more source billing views with an existing billing view. This allows creating aggregate billing views that combine data from multiple sources.
530 531 532 533 |
# File 'lib/aws-sdk-billing/client.rb', line 530 def associate_source_views(params = {}, = {}) req = build_request(:associate_source_views, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/aws-sdk-billing/client.rb', line 1277 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Billing') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-billing' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#create_billing_view(params = {}) ⇒ Types::CreateBillingViewResponse
Creates a billing view with the specified billing view attributes.
641 642 643 644 |
# File 'lib/aws-sdk-billing/client.rb', line 641 def create_billing_view(params = {}, = {}) req = build_request(:create_billing_view, params) req.send_request() end |
#delete_billing_view(params = {}) ⇒ Types::DeleteBillingViewResponse
Deletes the specified billing view.
688 689 690 691 |
# File 'lib/aws-sdk-billing/client.rb', line 688 def delete_billing_view(params = {}, = {}) req = build_request(:delete_billing_view, params) req.send_request() end |
#disassociate_source_views(params = {}) ⇒ Types::DisassociateSourceViewsResponse
Removes the association between one or more source billing views and an existing billing view. This allows modifying the composition of aggregate billing views.
739 740 741 742 |
# File 'lib/aws-sdk-billing/client.rb', line 739 def disassociate_source_views(params = {}, = {}) req = build_request(:disassociate_source_views, params) req.send_request() end |
#get_billing_view(params = {}) ⇒ Types::GetBillingViewResponse
Returns the metadata associated to the specified billing view ARN.
818 819 820 821 |
# File 'lib/aws-sdk-billing/client.rb', line 818 def get_billing_view(params = {}, = {}) req = build_request(:get_billing_view, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns the resource-based policy document attached to the resource in ‘JSON` format.
863 864 865 866 |
# File 'lib/aws-sdk-billing/client.rb', line 863 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#list_billing_views(params = {}) ⇒ Types::ListBillingViewsResponse
Lists the billing views available for a given time period.
Every Amazon Web Services account has a unique ‘PRIMARY` billing view that represents the billing data available by default. Accounts that use Billing Conductor also have `BILLING_GROUP` billing views representing pro forma costs associated with each created billing group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
985 986 987 988 |
# File 'lib/aws-sdk-billing/client.rb', line 985 def list_billing_views(params = {}, = {}) req = build_request(:list_billing_views, params) req.send_request() end |
#list_source_views_for_billing_view(params = {}) ⇒ Types::ListSourceViewsForBillingViewResponse
Lists the source views (managed Amazon Web Services billing views) associated with the billing view.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1043 1044 1045 1046 |
# File 'lib/aws-sdk-billing/client.rb', line 1043 def list_source_views_for_billing_view(params = {}, = {}) req = build_request(:list_source_views_for_billing_view, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with the billing view resource.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-billing/client.rb', line 1090 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
An API operation for adding one or more tags (key-value pairs) to a resource.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-billing/client.rb', line 1139 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource. Specify only tag keys in your request. Don’t specify the value.
1180 1181 1182 1183 |
# File 'lib/aws-sdk-billing/client.rb', line 1180 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_billing_view(params = {}) ⇒ Types::UpdateBillingViewResponse
An API to update the attributes of the billing view.
1268 1269 1270 1271 |
# File 'lib/aws-sdk-billing/client.rb', line 1268 def update_billing_view(params = {}, = {}) req = build_request(:update_billing_view, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1297 1298 1299 |
# File 'lib/aws-sdk-billing/client.rb', line 1297 def waiter_names [] end |