Class: Aws::Billing::Types::BillingViewElement
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::BillingViewElement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
The metadata associated to the billing view.
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
-
#billing_view_type ⇒ String
The type of billing group.
-
#created_at ⇒ Time
The time when the billing view was created.
-
#data_filter_expression ⇒ Types::Expression
See [Expression][1].
-
#derived_view_count ⇒ Integer
The number of billing views that use this billing view as a source.
-
#description ⇒ String
The description of the billing view.
-
#health_status ⇒ Types::BillingViewHealthStatus
The current health status of the billing view.
-
#name ⇒ String
The account name of the billing view.
-
#owner_account_id ⇒ String
The account owner of the billing view.
-
#source_account_id ⇒ String
The Amazon Web Services account ID that owns the source billing view, if this is a derived billing view.
-
#source_view_count ⇒ Integer
The number of source views associated with this billing view.
-
#updated_at ⇒ Time
The time when the billing view was last updated.
-
#view_definition_last_updated_at ⇒ Time
The timestamp of when the billing view definition was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#billing_view_type ⇒ String
The type of billing group.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The time when the billing view was created.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#data_filter_expression ⇒ Types::Expression
See Expression. Billing view only supports LINKED_ACCOUNT,
Tags, and CostCategories.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#derived_view_count ⇒ Integer
The number of billing views that use this billing view as a source.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#health_status ⇒ Types::BillingViewHealthStatus
The current health status of the billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The account name of the billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#owner_account_id ⇒ String
The account owner of the billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_account_id ⇒ String
The Amazon Web Services account ID that owns the source billing view, if this is a derived billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_view_count ⇒ Integer
The number of source views associated with this billing view.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The time when the billing view was last updated.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |
#view_definition_last_updated_at ⇒ Time
The timestamp of when the billing view definition was last updated.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-billing/types.rb', line 263 class BillingViewElement < Struct.new( :arn, :name, :description, :billing_view_type, :owner_account_id, :source_account_id, :data_filter_expression, :created_at, :updated_at, :derived_view_count, :source_view_count, :view_definition_last_updated_at, :health_status) SENSITIVE = [:name, :description] include Aws::Structure end |