Class: Aws::Billing::Types::ChargeAccount
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::ChargeAccount
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
An account that is charged all or a portion of the total Support charge and the percentage of the charge allocated to it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID.
-
#charge_percentage ⇒ String
The percentage of the total Support charge allocated to this account.
Instance Attribute Details
#account_id ⇒ String
The account ID.
401 402 403 404 405 406 |
# File 'lib/aws-sdk-billing/types.rb', line 401 class ChargeAccount < Struct.new( :account_id, :charge_percentage) SENSITIVE = [] include Aws::Structure end |
#charge_percentage ⇒ String
The percentage of the total Support charge allocated to this account. This is 0.0 when supportAllocationMethod = Proportional.
401 402 403 404 405 406 |
# File 'lib/aws-sdk-billing/types.rb', line 401 class ChargeAccount < Struct.new( :account_id, :charge_percentage) SENSITIVE = [] include Aws::Structure end |