Class: Aws::Billing::Types::ContractAccount
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::ContractAccount
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
An account that is covered by the Enterprise Support contract.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID.
-
#is_gdn ⇒ Boolean
When true, Support charges are calculated on charges before private discounts.
Instance Attribute Details
#account_id ⇒ String
The account ID.
446 447 448 449 450 451 |
# File 'lib/aws-sdk-billing/types.rb', line 446 class ContractAccount < Struct.new( :account_id, :is_gdn) SENSITIVE = [] include Aws::Structure end |
#is_gdn ⇒ Boolean
When true, Support charges are calculated on charges before private discounts. When false, they are calculated after private discounts.
446 447 448 449 450 451 |
# File 'lib/aws-sdk-billing/types.rb', line 446 class ContractAccount < Struct.new( :account_id, :is_gdn) SENSITIVE = [] include Aws::Structure end |