Class: Aws::Billing::Types::CreditAllocationHistoryEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::CreditAllocationHistoryEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
A single entry in the credit allocation history, representing how a credit was applied to a specific service during a billing month.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account the credit was applied to.
-
#applied_service_name ⇒ String
The Amazon Web Services service the credit was applied to.
-
#billing_month ⇒ String
The billing month of the application in
YYYY-MMformat. -
#credit_amount ⇒ Types::Amount
The amount of credit applied.
-
#credit_id ⇒ String
The identifier of the credit that was applied.
-
#description ⇒ String
A human-readable description of the credit allocation.
-
#is_estimated_bill ⇒ Boolean
truewhen the entry was applied to an in-flight bill that has not yet been finalized.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account the credit was applied to.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |
#applied_service_name ⇒ String
The Amazon Web Services service the credit was applied to.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |
#billing_month ⇒ String
The billing month of the application in YYYY-MM format.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |
#credit_amount ⇒ Types::Amount
The amount of credit applied. Negative values represent credits that reduced the bill.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |
#credit_id ⇒ String
The identifier of the credit that was applied.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable description of the credit allocation.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |
#is_estimated_bill ⇒ Boolean
true when the entry was applied to an in-flight bill that has not
yet been finalized.
511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/aws-sdk-billing/types.rb', line 511 class CreditAllocationHistoryEntry < Struct.new( :credit_id, :credit_amount, :description, :account_id, :applied_service_name, :billing_month, :is_estimated_bill) SENSITIVE = [] include Aws::Structure end |