Class: Aws::Billing::Types::DeleteBillingViewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::DeleteBillingViewRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
-
#force ⇒ Boolean
If set to true, forces deletion of the billing view even if it has derived resources (e.g. other billing views or budgets).
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
722 723 724 725 726 727 |
# File 'lib/aws-sdk-billing/types.rb', line 722 class DeleteBillingViewRequest < Struct.new( :arn, :force) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
If set to true, forces deletion of the billing view even if it has derived resources (e.g. other billing views or budgets). Use with caution as this may break dependent resources.
722 723 724 725 726 727 |
# File 'lib/aws-sdk-billing/types.rb', line 722 class DeleteBillingViewRequest < Struct.new( :arn, :force) SENSITIVE = [] include Aws::Structure end |