Class: Aws::Billing::Types::DeleteBillingViewRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.

Returns:

  • (String)


657
658
659
660
661
662
# File 'lib/aws-sdk-billing/types.rb', line 657

class DeleteBillingViewRequest < Struct.new(
  :arn,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

If set to true, forces deletion of the billing view even if it has derived resources (e.g. other billing views or budgets). Use with caution as this may break dependent resources.

Returns:

  • (Boolean)


657
658
659
660
661
662
# File 'lib/aws-sdk-billing/types.rb', line 657

class DeleteBillingViewRequest < Struct.new(
  :arn,
  :force)
  SENSITIVE = []
  include Aws::Structure
end