Class: Aws::Billing::Types::GetEnterpriseSupportChargeSummaryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::GetEnterpriseSupportChargeSummaryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
The response structure for GetEnterpriseSupportChargeSummary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bill_date ⇒ Time
The date the bill was generated.
-
#billing_month ⇒ String
The billing month in YYYY-MM format.
-
#billing_period_end_date ⇒ Time
The end date of the billing period.
-
#billing_period_start_date ⇒ Time
The start date of the billing period.
-
#is_estimated ⇒ Boolean
When true, the Support charge amount is estimated.
-
#payer_account_id ⇒ String
The payer account ID that is authorized to view Enterprise Support data for all accounts in its Support profile.
-
#support_charge ⇒ String
The Support charge amount for the account.
-
#support_charge_percentage ⇒ String
The percentage applied to the total Support-eligible spend to calculate the total Support charge across all accounts in the Support profile.
-
#support_discount ⇒ String
The support discount amount.
-
#support_effective_pricing_plan ⇒ Types::PricingPlan
The effective pricing plan used for the support charge calculation.
-
#total_support_charge ⇒ String
The total Support charge amount for all accounts in the Support profile.
-
#total_support_eligible_reserved_instance_spend ⇒ String
The total Support-eligible Reserved Instance spend from all accounts in the Support profile.
-
#total_support_eligible_savings_plan_spend ⇒ String
The total Support-eligible Savings Plan spend from all accounts in the Support profile.
-
#total_support_eligible_spend ⇒ String
The total Support-eligible Spend from all accounts in the Support profile.
-
#total_support_eligible_usage_spend ⇒ String
The total Support-eligible spend from usage of Amazon Web Services from all accounts in the Support profile.
Instance Attribute Details
#bill_date ⇒ Time
The date the bill was generated.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#billing_month ⇒ String
The billing month in YYYY-MM format. This must be a month in the past.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#billing_period_end_date ⇒ Time
The end date of the billing period.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#billing_period_start_date ⇒ Time
The start date of the billing period.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#is_estimated ⇒ Boolean
When true, the Support charge amount is estimated. When false, the Support charge amount is finalized.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#payer_account_id ⇒ String
The payer account ID that is authorized to view Enterprise Support data for all accounts in its Support profile.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#support_charge ⇒ String
The Support charge amount for the account.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#support_charge_percentage ⇒ String
The percentage applied to the total Support-eligible spend to calculate the total Support charge across all accounts in the Support profile.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#support_discount ⇒ String
The support discount amount.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#support_effective_pricing_plan ⇒ Types::PricingPlan
The effective pricing plan used for the support charge calculation.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#total_support_charge ⇒ String
The total Support charge amount for all accounts in the Support profile.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_reserved_instance_spend ⇒ String
The total Support-eligible Reserved Instance spend from all accounts in the Support profile.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_savings_plan_spend ⇒ String
The total Support-eligible Savings Plan spend from all accounts in the Support profile.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_spend ⇒ String
The total Support-eligible Spend from all accounts in the Support profile. This includes eligible spend from usage of Amazon Web Services, Reserved Instances, and Savings Plans.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_usage_spend ⇒ String
The total Support-eligible spend from usage of Amazon Web Services from all accounts in the Support profile.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-billing/types.rb', line 1134 class GetEnterpriseSupportChargeSummaryResponse < Struct.new( :payer_account_id, :billing_month, :billing_period_start_date, :billing_period_end_date, :is_estimated, :bill_date, :support_charge, :total_support_charge, :support_discount, :total_support_eligible_spend, :total_support_eligible_usage_spend, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_charge_percentage, :support_effective_pricing_plan) SENSITIVE = [] include Aws::Structure end |