Class: Aws::Billing::Types::GetEnterpriseSupportContractDetailsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::GetEnterpriseSupportContractDetailsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
The response structure for GetEnterpriseSupportContractDetails.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_support_charge ⇒ Array<Types::AdditionalCharge>
Any Additional support charges applied to the contract.
-
#additional_support_eligible_usage_spend ⇒ Array<Types::AdditionalCharge>
Any Additional support-eligible usage spend charges.
-
#charged_payer_account_ids ⇒ Array<Types::ChargeAccount>
The list of payer accounts and their charge allocation percentages.
-
#contract_payer_account_ids ⇒ Array<Types::ContractAccount>
The list of accounts covered by the Enterprise Support contract.
-
#is_contract_active ⇒ Boolean
When true, the Enterprise Support contract is active.
-
#pricing_plans ⇒ Array<Types::PricingPlan>
The pricing plans associated with this Enterprise Support contract.
-
#support_allocation_method ⇒ String
The method used to distribute the total Support charge amount across each account in the Support profile.
-
#support_prorate_start_date ⇒ Time
The start date for accounts subscribed or unsubscribed to Support billing during the billing month.
-
#support_reserved_instance_amortization_start_date ⇒ Time
When supportReservedInstanceTreatmentMethod = AmortizedCustom, only amortized fees for Reserved Instances purchased on or after this date are included in the calculation.
-
#support_reserved_instance_treatment_method ⇒ String
The method used to include Reserved Instance (RI) fees in the Enterprise Support charge calculation.
-
#support_savings_plans_amortization_start_date ⇒ Time
This is applicable when supportSavingsPlansTreatmentMethod = Amortized and is Null for all other methods.
-
#support_savings_plans_treatment_method ⇒ String
The method used to include Savings Plans fees in Enterprise Support charge calculations.
Instance Attribute Details
#additional_support_charge ⇒ Array<Types::AdditionalCharge>
Any Additional support charges applied to the contract.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#additional_support_eligible_usage_spend ⇒ Array<Types::AdditionalCharge>
Any Additional support-eligible usage spend charges.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#charged_payer_account_ids ⇒ Array<Types::ChargeAccount>
The list of payer accounts and their charge allocation percentages.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#contract_payer_account_ids ⇒ Array<Types::ContractAccount>
The list of accounts covered by the Enterprise Support contract.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#is_contract_active ⇒ Boolean
When true, the Enterprise Support contract is active. When false, the Enterprise Support Contract is inactive.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#pricing_plans ⇒ Array<Types::PricingPlan>
The pricing plans associated with this Enterprise Support contract.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#support_allocation_method ⇒ String
The method used to distribute the total Support charge amount across each account in the Support profile. Valid values: Proportional, Fixed_Percentage. Proportional means support charges are distributed to each account in proportion to its eligible Spend. Fixed_Percentage means support charges are distributed across accounts according to pre-configured percentages from the contract.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#support_prorate_start_date ⇒ Time
The start date for accounts subscribed or unsubscribed to Support billing during the billing month.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#support_reserved_instance_amortization_start_date ⇒ Time
When supportReservedInstanceTreatmentMethod = AmortizedCustom, only amortized fees for Reserved Instances purchased on or after this date are included in the calculation. This field is Null for all other treatment methods.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#support_reserved_instance_treatment_method ⇒ String
The method used to include Reserved Instance (RI) fees in the Enterprise Support charge calculation. Valid values: None (RI fees excluded from Support-eligible spend), Upfront (full upfront RI fees included in month of purchase), Amortized (RI fees spread over commitment term for RIs purchased on or after Support subscription start date), AmortizedCustom (same as Amortized but only for RIs purchased on or after a specified custom start date), AmortizedAll (RI fees amortized for all active RIs including those purchased before Support subscription started).
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#support_savings_plans_amortization_start_date ⇒ Time
This is applicable when supportSavingsPlansTreatmentMethod = Amortized and is Null for all other methods. It shows the start date from which Savings Plan fees are included in Support Eligible Spend.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |
#support_savings_plans_treatment_method ⇒ String
The method used to include Savings Plans fees in Enterprise Support charge calculations. Valid values: None (Savings Plan fees excluded from Support-eligible spend), Upfront (full upfront Savings Plan fees included in month of purchase), Amortized (Savings Plan fees spread over commitment term for Savings Plans purchased on or after Support subscription start date), AmortizedCustom (same as Amortized but only for Savings Plans purchased on or after a specified custom start date), AmortizedAll (Savings Plan fees amortized for all active Savings Plans including those purchased before Support subscription started).
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'lib/aws-sdk-billing/types.rb', line 1250 class GetEnterpriseSupportContractDetailsResponse < Struct.new( :is_contract_active, :support_allocation_method, :support_reserved_instance_amortization_start_date, :support_reserved_instance_treatment_method, :support_savings_plans_amortization_start_date, :support_savings_plans_treatment_method, :support_prorate_start_date, :contract_payer_account_ids, :charged_payer_account_ids, :additional_support_charge, :additional_support_eligible_usage_spend, :pricing_plans) SENSITIVE = [] include Aws::Structure end |