Class: Aws::Billing::Types::LinkedAccountCharge
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::LinkedAccountCharge
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
Enterprise Support charges for a linked account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The linked account ID.
-
#account_type ⇒ String
The type of account.
-
#billable_seconds ⇒ Integer
The number of billable seconds in the billing period based on when the account was subscribed to Enterprise Support.
-
#linked_time_periods ⇒ Array<Types::EnterpriseSupportTimePeriod>
The time periods during which this account was linked.
-
#payer_account_id ⇒ String
The payer account ID that is authorized to view Enterprise Support data for all accounts in its Support profile.
-
#prorated_total_support_eligible_spend ⇒ String
The prorated total support-eligible spend based on when the account was subscribed to Enterprise Support.
-
#subscription_time_periods ⇒ Array<Types::EnterpriseSupportTimePeriod>
The subscription time periods for this account.
-
#support_eligible_spend_by_service ⇒ Array<Types::ServiceLevelAccountUsage>
The support-eligible spend broken down by service.
-
#total_seconds ⇒ Integer
The total number of seconds in the billing period.
-
#total_support_eligible_reserved_instance_spend ⇒ String
The total support-eligible Reserved Instance spend for this account.
-
#total_support_eligible_savings_plan_spend ⇒ String
The total support-eligible Savings Plan spend for this account.
-
#total_support_eligible_spend ⇒ String
The total support-eligible spend for this account.
Instance Attribute Details
#account_id ⇒ String
The linked account ID.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#account_type ⇒ String
The type of account.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#billable_seconds ⇒ Integer
The number of billable seconds in the billing period based on when the account was subscribed to Enterprise Support.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#linked_time_periods ⇒ Array<Types::EnterpriseSupportTimePeriod>
The time periods during which this account was linked.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#payer_account_id ⇒ String
The payer account ID that is authorized to view Enterprise Support data for all accounts in its Support profile.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#prorated_total_support_eligible_spend ⇒ String
The prorated total support-eligible spend based on when the account was subscribed to Enterprise Support.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#subscription_time_periods ⇒ Array<Types::EnterpriseSupportTimePeriod>
The subscription time periods for this account.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#support_eligible_spend_by_service ⇒ Array<Types::ServiceLevelAccountUsage>
The support-eligible spend broken down by service.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#total_seconds ⇒ Integer
The total number of seconds in the billing period.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_reserved_instance_spend ⇒ String
The total support-eligible Reserved Instance spend for this account.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_savings_plan_spend ⇒ String
The total support-eligible Savings Plan spend for this account.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |
#total_support_eligible_spend ⇒ String
The total support-eligible spend for this account.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/aws-sdk-billing/types.rb', line 1368 class LinkedAccountCharge < Struct.new( :account_id, :payer_account_id, :account_type, :billable_seconds, :total_seconds, :total_support_eligible_spend, :prorated_total_support_eligible_spend, :linked_time_periods, :subscription_time_periods, :total_support_eligible_reserved_instance_spend, :total_support_eligible_savings_plan_spend, :support_eligible_spend_by_service) SENSITIVE = [] include Aws::Structure end |