Class: Aws::Billing::Types::ListBillingViewsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::ListBillingViewsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_time_range ⇒ Types::ActiveTimeRange
The time range for the billing views listed.
-
#arns ⇒ Array<String>
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
-
#billing_view_types ⇒ Array<String>
The type of billing view.
-
#max_results ⇒ Integer
The maximum number of billing views to retrieve.
-
#names ⇒ Array<Types::StringSearch>
Filters the list of billing views by name.
-
#next_token ⇒ String
The pagination token that is used on subsequent calls to list billing views.
-
#owner_account_id ⇒ String
The list of owners of the billing view.
-
#source_account_id ⇒ String
Filters the results to include only billing views that use the specified account as a source.
Instance Attribute Details
#active_time_range ⇒ Types::ActiveTimeRange
The time range for the billing views listed. PRIMARY billing view is always listed. BILLING_GROUP billing views are listed for time ranges when the associated billing group resource in Billing Conductor is active. The time range must be within one calendar month.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#arns ⇒ Array<String>
The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#billing_view_types ⇒ Array<String>
The type of billing view.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of billing views to retrieve. Default is 100.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#names ⇒ Array<Types::StringSearch>
Filters the list of billing views by name. You can specify search criteria to match billing view names based on the search option provided.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that is used on subsequent calls to list billing views.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#owner_account_id ⇒ String
The list of owners of the billing view.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#source_account_id ⇒ String
Filters the results to include only billing views that use the specified account as a source.
585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-billing/types.rb', line 585 class ListBillingViewsRequest < Struct.new( :active_time_range, :arns, :billing_view_types, :names, :owner_account_id, :source_account_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |