Class: Aws::Billing::Types::PricingPlan
- Inherits:
-
Struct
- Object
- Struct
- Aws::Billing::Types::PricingPlan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billing/types.rb
Overview
A pricing plan for Enterprise Support billing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the pricing plan.
-
#discount_applies_to_minimum_charge ⇒ Boolean
Whether the discount applies to the minimum Support charge.
-
#end_date ⇒ Time
The end date of the pricing plan.
-
#minimum_charge ⇒ String
The minimum Support charge amount for this pricing plan.
-
#name ⇒ String
The name of the pricing plan.
-
#plan_discount_percent ⇒ String
The discount percentage applied by this pricing plan.
-
#pricing_plan_id ⇒ String
The unique identifier for the pricing plan.
-
#start_date ⇒ Time
The start date of the pricing plan.
-
#tiered ⇒ String
Whether the pricing plan uses tiered pricing.
-
#tiers ⇒ Array<Types::PricingPlanTier>
The pricing tiers within this plan.
Instance Attribute Details
#description ⇒ String
A description of the pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#discount_applies_to_minimum_charge ⇒ Boolean
Whether the discount applies to the minimum Support charge.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The end date of the pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#minimum_charge ⇒ String
The minimum Support charge amount for this pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#plan_discount_percent ⇒ String
The discount percentage applied by this pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#pricing_plan_id ⇒ String
The unique identifier for the pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The start date of the pricing plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#tiered ⇒ String
Whether the pricing plan uses tiered pricing.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |
#tiers ⇒ Array<Types::PricingPlanTier>
The pricing tiers within this plan.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-billing/types.rb', line 1620 class PricingPlan < Struct.new( :pricing_plan_id, :name, :description, :start_date, :end_date, :plan_discount_percent, :discount_applies_to_minimum_charge, :minimum_charge, :tiered, :tiers) SENSITIVE = [] include Aws::Structure end |